@@ -25,7 +25,8 @@ test_that("basic run", {
     N_e = 2,
     n_filled = 1,
     R = 1e-7,
-    method = "par"
+    method = "par",
+    cores = 1
   ))
 
   ## check cluster system
