@@ -25,7 +25,8 @@ test_that("basic run", {
     clusters = 1e1,
     n_filled = 1,
     r = 1e-7,
-    method = "par"
+    method = "par",
+    cores = 1
   ))
 
   ##check cluster system
